@@ -140,7 +140,7 @@ sub new {
 
 package Class::OWL;
 
-use version; $VERSION = qv('0.0.4');
+use version; $VERSION = qv('0.0.5');
 
 use warnings;
 use strict;
@@ -598,12 +598,12 @@ __END__
 
 =head1 NAME
 
-Class::OWL - [One line description of module's purpose here]
+Class::OWL - Generate perl classes from OWL schema
 
 
 =head1 VERSION
 
-This document describes Class::OWL version 0.0.1
+This document describes Class::OWL version 0.0.5
 
 
 =head1 SYNOPSIS
@@ -617,28 +617,10 @@ This document describes Class::OWL version 0.0.1
   
 =head1 DESCRIPTION
 
-=for author to fill in:
-    Write a full description of the module and its features here.
-    Use subsections (=head2, =head3) as appropriate.
-
-
 =head1 INTERFACE 
 
-=for author to fill in:
-    Write a separate section listing the public components of the modules
-    interface. These normally consist of either subroutines that may be
-    exported, or methods that may be called on objects belonging to the
-    classes provided by the module.
-
-
 =head1 DIAGNOSTICS
 
-=for author to fill in:
-    List every single error and warning message that the module can
-    generate (even the ones that will "never happen"), with a full
-    explanation of each problem, one or more likely causes, and any
-    suggested remedies.
-
 =over
 
 =item C<< Error message here, perhaps with %s placeholders >>
@@ -656,13 +638,6 @@ This document describes Class::OWL version 0.0.1
 
 =head1 CONFIGURATION AND ENVIRONMENT
 
-=for author to fill in:
-    A full explanation of any configuration system(s) used by the
-    module, including the names and locations of any configuration
-    files, and the meaning of any environment variables or properties
-    that can be set. These descriptions must also include details of any
-    configuration language used.
-  
 Class::OWL requires no configuration files or environment variables.
 
 
@@ -673,27 +648,11 @@ Class::MOP, RDF::Helper, LWP::Simple, XML::CommonNS
 
 =head1 INCOMPATIBILITIES
 
-=for author to fill in:
-    A list of any modules that this module cannot be used in conjunction
-    with. This may be due to name conflicts in the interface, or
-    competition for system or program resources, or due to internal
-    limitations of Perl (for example, many modules that use source code
-    filters are mutually incompatible).
-
 None reported.
 
 
 =head1 BUGS AND LIMITATIONS
 
-=for author to fill in:
-    A list of known problems with the module, together with some
-    indication Whether they are likely to be fixed in an upcoming
-    release. Also a list of restrictions on the features the module
-    does provide: data types that cannot be handled, performance issues
-    and the circumstances in which they may arise, practical
-    limitations on the size of data sets, special cases that are not
-    (yet) handled, etc.
-
 No bugs have been reported.
 
 Please report any bugs or feature requests to
@@ -704,7 +663,7 @@ L<http://rt.cpan.org>.
 =head1 AUTHOR
 
 Chris Prather  C<< <cpan@prather.org> >>
-
+Leif Johansson C<< <leifj@it.su.se> >>
 
 =head1 LICENCE AND COPYRIGHT
 
